# -*- coding: utf-8 -*-
# -*- indent-tabs-mode: t -*-
#
# Copyright (c) 2003-2005 Kouhei Sutou <kou@cozmixng.org>
# Distributed under the GPL
#

def label_recent_rss_title
	'外部RSSの表示'
end

def label_recent_rss_use_image_link_title
	'画像の扱い'
end

def label_recent_rss_use_image_link_description
	'もしRSSにWebサイトの画像情報が含まれていたら，' +
		'Webサイトへのリンクにテキストではなくその画像を用います．'
end

def label_recent_rss_not_use_image_link
	'リンクに画像を用いない'
end

def label_recent_rss_use_image_link
	'リンクに画像を用いる'
end

# Local Variables:
# mode: ruby
# indent-tabs-mode: t
# tab-width: 3
# ruby-indent-level: 3
# End:
